DROP VIEW IF EXISTS cpol_violations_v;
DROP VIEW IF EXISTS cpol_admins_v;

CREATE VIEW cpol_admins_v AS
 SELECT DISTINCT 
	admins.display_name AS policy_admin, 
	admins.unique_user_id AS admin_id, 
	cp.id AS policy_id
 FROM suser admins
 LEFT JOIN certification_policy_admin cpa ON cpa.admin_unique_id = admins.unique_user_id AND admins.effective = true
 LEFT JOIN certification_policy cp ON cpa.cert_policy_id = cp.id 
 WHERE cp.is_active = true;

CREATE VIEW cpol_violations_v AS
SELECT
	cp.created_by,
	cp.changed_by,
	cp.id,
	cp.unique_id AS cert_unique_id,
	cp.name AS cpol,
	cp.description,
	cp.validity_period,
	admins.admin_name AS administrators,
	cp.risk,
	cp.cp_total_violation,
	cp.deleted,
	cp.remediation_type,
	rd.name AS review_name,
	rd.id AS review_id,
	rd.description AS review_description,
	rd.review_type,
	rd.review_target_type,
	cpv.violation_type,
	cpv.violation_status,
	cpv.created_date,
	cpv.resolved_date,
	cpv.last_detected_date,
	saccount.name AS account_violator,
	saccount.unique_account_id,
	saccount.description AS account_desc,
	cust.account_custodian,
	spermission.name AS permission_violator,
	spermission.unique_permission_id,
	spermission.description AS permission_desc,
	suser.display_name AS user_violator,
	suser.user_id,
	suser.unique_user_id,
	suser.display_description AS user_desc,
	sup.display_name AS supervisor_name,
	sup.unique_user_id AS supervisor_id,
	role.name AS role_violator,
	role.unique_policy_id AS role_qid,
	role.description AS role_desc,
	brole.name AS brole_violator,
	brole.unique_id AS brole_qid,
	brole.description AS brole_desc
FROM certification_policy cp
	LEFT JOIN remediation remed ON cp.unique_id = remed.policy_unique_id AND remed.is_active = true
	LEFT JOIN cert_policy_review_defs cprd ON cp.id = cprd.cert_policy_id
	LEFT JOIN review_definition rd ON cprd.review_definition_unique_id = rd.unique_review_def_id AND rd.is_active = true
	JOIN cert_policy_violation cpv ON rd.unique_review_def_id = cpv.review_definition_unique_id
	LEFT JOIN ( SELECT cp_1.id,
				string_agg(admins_1.display_name, ' | ' ORDER BY cp_1.id) AS admin_name
				FROM suser admins_1
					LEFT JOIN certification_policy_admin cpa ON cpa.admin_unique_id = admins_1.unique_user_id AND admins_1.effective = true
					LEFT JOIN certification_policy cp_1 ON cpa.cert_policy_id = cp_1.id
				WHERE cp_1.is_active = true
				GROUP BY cp_1.id) admins ON cp.id = admins.id
	LEFT JOIN saccount ON cpv.unique_account_id = saccount.unique_account_id AND saccount.effective = true
	LEFT JOIN (SELECT sacc.unique_account_id, 
				string_agg(cust.display_name, ' | ' ORDER BY sacc.unique_account_id) AS account_custodian
				FROM saccount sacc 
					LEFT JOIN resolved_saccount_owner rso ON sacc.id = rso.account AND sacc.effective = true
					LEFT JOIN suser cust ON rso.owner_unique_id = cust.unique_user_id
				WHERE cust.effective = true 
				GROUP BY sacc.unique_account_id) cust ON cust.unique_account_id = saccount.unique_account_id   
	LEFT JOIN spermission ON cpv.unique_permission_id = spermission.unique_permission_id AND spermission.effective = true
	LEFT JOIN suser ON cpv.unique_user_id = suser.unique_user_id AND suser.effective = true
	LEFT JOIN suser sup ON sup.unique_user_id = suser.supervisor_unique_id AND sup.effective = true
	LEFT JOIN role_policy role ON cpv.role_id = role.id AND role.state = 'ACTIVE' AND role.deleted = false
	LEFT JOIN business_role brole ON cpv.business_role_id = brole.id
WHERE cp.is_active = true;

ALTER TABLE cpol_violations_v
  OWNER TO igops;
GRANT ALL ON TABLE cpol_violations_v TO igops;
GRANT SELECT ON TABLE cpol_violations_v TO ig_report_role;

ALTER TABLE cpol_admins_v
  OWNER TO igops;
GRANT ALL ON TABLE cpol_admins_v TO igops;
GRANT SELECT ON TABLE cpol_admins_v TO ig_report_role;